@@ -6,8 +6,6 @@
 #include "input.h"
 #include "nxp_proto.h"
 
-int hwload_mode = 1;        ///< hwload_mode = 1 means read hardware once. should be enough
-
 // Device list
 usbdevice keyboard[DEV_MAX];    ///< remember all usb devices. Needed for closeusb().
 queued_mutex_t devmutex[DEV_MAX] = { [0 ... DEV_MAX-1] = QUEUED_MUTEX_INITIALIZER };        ///< Mutex for handling the usbdevice structure
@@ -149,28 +147,11 @@ int init_cond_monotonic(void) {
 ///
 int _start_dev(usbdevice* kb, int makeactive){
     // Get the firmware version from the device
-    if(kb->pollrate == 0){
-        ///
-        /// - This hacker code is tricky in mutliple aspects. What it means is:
-        /// \n if hwload_mode == 0: just set pollrate to 0 and clear features in the bottom lines of the if-block.
-        /// \n if hwload_mode == 1: if the device has FEAT_HWLOAD active, call getfwversion(). If it returns true, there was an error while detecting fw-version. Put error message, reset FEAT_HWLOAD and finalize as above.
-        /// \n if hwload_mode == 2: if the device has FEAT_HWLOAD active, call getfwversion(). If it returns true, there was an error while detecting fw-version. Put error message and return directly from function with error.
-        /// \n Why do not you just write it down?
-        ///
-        if(!hwload_mode || (HAS_FEATURES(kb, FEAT_HWLOAD) && getfwversion(kb))){
-            if(hwload_mode == 2)
-                // hwload=always. Report setup failure.
-                return -1;
-            else if(hwload_mode){
-                // hwload=once. Log failure, prevent trying again, and continue.
-                ckb_warn("Unable to load firmware version/poll rate");
-                kb->features &= ~FEAT_HWLOAD;
-            }
-            kb->pollrate = 0;
-            kb->features &= ~(FEAT_POLLRATE | FEAT_ADJRATE);
-            if(kb->fwversion == 0)
-                kb->features &= ~(FEAT_FWVERSION | FEAT_FWUPDATE);
-        }
+    if(getfwversion(kb)){
+        ckb_warn("Unable to load firmware version/poll rate");
+        kb->features &= ~(FEAT_POLLRATE | FEAT_ADJRATE | FEAT_HWLOAD);
+        if(!kb->fwversion)
+            kb->features &= ~(FEAT_FWVERSION | FEAT_FWUPDATE);
     }
     ///
     /// SINGLE EP devices do not have any input, thus do not supporting binding.
@@ -207,7 +188,7 @@ int _start_dev(usbdevice* kb, int makeactive){
     if(NEEDS_FW_UPDATE(kb)){
         /// - Device needs a firmware update. Finish setting up but don't do anything.
         ckb_info("Device needs a firmware update. Please issue a fwupdate command.");
-        kb->features = FEAT_RGB | FEAT_FWVERSION | FEAT_FWUPDATE;
+        kb->features = FEAT_FWVERSION | FEAT_FWUPDATE;
         kb->active = 1;
         return 0;
     }
@@ -216,10 +197,8 @@ int _start_dev(usbdevice* kb, int makeactive){
     /// \n return error if mode == 2 (load always) and loading got an error. Else reset HWLOAD feature, because hwload must be 1.
     /// \n\n That is real Horror code.
     ///
-    if(!kb->hw && hwload_mode && HAS_FEATURES(kb, FEAT_HWLOAD)){
+    if(!kb->hw && HAS_FEATURES(kb, FEAT_HWLOAD)){
         if(hwloadprofile(kb, 1)){
-            if(hwload_mode == 2)
-                return -1;
             ckb_warn("Unable to load hardware profile");
             kb->features &= ~FEAT_HWLOAD;
         }
@@ -240,10 +219,12 @@ int _start_dev(usbdevice* kb, int makeactive){
 }
 
 int start_dev(usbdevice* kb, int makeactive){
-    // Force USB interval to 10ms during initial setup phase; return to nominal 5ms after setup completes.
-    kb->usbdelay = 10;
+    // Force USB interval to 10ms during initial setup phase; assume 30FPS afterwards.
+    kb->usbdelay_ns = 10000000L;
+    kb->maxpollrate = POLLRATE_1MS;
+    kb->pollrate = POLLRATE_UNKNOWN;
     int res = _start_dev(kb, makeactive);
-    kb->usbdelay = USB_DELAY_DEFAULT;
+    kb->vtable.setfps(kb, 30);
     return res;
 }
 
@@ -297,5 +278,34 @@ void nxp_get_battery_info(usbdevice* kb){
         return;
     }
     kb->battery_level = nxp_battery_lut[in[4]];
+    switch (in[5]) {
+        case 1:
+            in[5] = 2;
+            break;
+        case 2:
+            in[5] = 1;
+            break;
+    }
     kb->battery_status = in[5];
 }
+
+void nxp_delay(usbdevice* kb, delay_type_t type){
+    long delay;
+    switch(type){
+    case DELAY_SEND:
+        delay = kb->usbdelay_ns;
+        break;
+    case DELAY_RECV:
+        if(kb->fwversion >= 0x120 || IS_V2_OVERRIDE(kb))
+            return;
+        delay = kb->usbdelay_ns * 10;
+        break;
+    case DELAY_INDICATORS:
+        delay = kb->usbdelay_ns;
+        break;
+    default:
+        ckb_err("Invalid delay type %d", type);
+        delay = 5000000L;
+    }
+    clock_nanosleep(CLOCK_MONOTONIC, 0, &(struct timespec) {.tv_nsec = delay}, NULL);
+}
