@@ -1,6 +1,6 @@
 // Keymap patches for specific devices
 typedef struct {
-    int idx; // Index of key to patch in keymap
+    size_t idx; // Index of key to patch in keymap
     const char* name;
     short led;
     short scan;
@@ -10,8 +10,8 @@ typedef struct {
 typedef struct {
     ushort vendor;
     ushort product;
-    keypatch* patch;
-    unsigned patchlen;
+    const keypatch* patch;
+    size_t patchlen;
 } keypatches;
 
 ///
