@@ -2,23 +2,40 @@
 #include "notify.h"
 #include "profile.h"
 #include "usb.h"
+#include "nxp_proto.h"
+#include "dpi.h"
+#include <stdbool.h>
 
 // Compare two light structures, ignore keys
-static int rgbcmp(const lighting* lhs, const lighting* rhs){
+static inline int rgbcmp(const lighting* lhs, const lighting* rhs){
     return memcmp(lhs->r + LED_MOUSE, rhs->r + LED_MOUSE, N_MOUSE_ZONES) || memcmp(lhs->g + LED_MOUSE, rhs->g + LED_MOUSE, N_MOUSE_ZONES) || memcmp(lhs->b + LED_MOUSE, rhs->b + LED_MOUSE, N_MOUSE_ZONES);
 }
 
+static inline int dpirgbcmp(const lighting* lhs, const lighting* rhs){
+    return memcmp(lhs->r + DPI_RGB_START, rhs->r + DPI_RGB_START, DPI_COUNT) || memcmp(lhs->g + DPI_RGB_START, rhs->g + DPI_RGB_START, DPI_COUNT) || memcmp(lhs->b + DPI_RGB_START, rhs->b + DPI_RGB_START, DPI_COUNT);
+}
+
 int updatergb_mouse(usbdevice* kb, int force){
     if(!kb->active)
         return 0;
     lighting* lastlight = &kb->profile->lastlight;
     lighting* newlight = &kb->profile->currentmode->light;
+    bool fupdate = force || lastlight->forceupdate || newlight->forceupdate;
+
+    // Force a DPI update if the rgb0-rgb5 zones have changed
+    // This needs to be above the main rgbcmp check as it doesn't return
+    if(NXP_RGB_IN_DPI_PKT(kb) && (fupdate || dpirgbcmp(lastlight, newlight)))
+        updatedpi(kb, 1);
+
     // Don't do anything if the lighting hasn't changed
-    if(!force && !lastlight->forceupdate && !newlight->forceupdate
-            && !rgbcmp(lastlight, newlight))
+    if(!(fupdate || rgbcmp(lastlight, newlight)))
         return 0;
     lastlight->forceupdate = newlight->forceupdate = 0;
 
+    // The Dark Core has its own lighting protocol.
+    if(IS_DARK_CORE_NXP(kb))
+        return updatergb_wireless(kb, lastlight, newlight);
+
     // Prevent writing to DPI LEDs or non-existent LED zones for the Glaive.
     int num_zones = IS_GLAIVE(kb) ? 3 : N_MOUSE_ZONES;
     // Send the RGB values for each zone to the mouse
@@ -33,7 +50,7 @@ int updatergb_mouse(usbdevice* kb, int force){
         *rgb_data++ = newlight->b[LED_MOUSE + i];
     }
     // Send RGB data
-    if(!usbsend(kb, data_pkt, 1))
+    if(!usbsend(kb, data_pkt, sizeof(data_pkt), 1))
         return -1;
 
     memcpy(lastlight, newlight, sizeof(lighting));
@@ -53,7 +70,7 @@ int savergb_mouse(usbdevice* kb, lighting* light, int mode){
         data_pkt[4] = light->r[led];
         data_pkt[5] = light->g[led];
         data_pkt[6] = light->b[led];
-        if(!usbsend(kb, data_pkt, 1))
+        if(!usbsend(kb, data_pkt, sizeof(data_pkt), 1))
             return -1;
         // Set packet for next zone
         data_pkt[2]++;
@@ -69,7 +86,7 @@ int loadrgb_mouse(usbdevice* kb, lighting* light, int mode){
     // Load each RGB zone
     int zonecount = IS_SCIMITAR(kb) ? 4 : IS_SABRE(kb) ? 3 : 2;
     for(int i = 0; i < zonecount; i++){
-        if(!usbrecv(kb, data_pkt, in_pkt))
+        if(!usbrecv(kb, data_pkt, sizeof(data_pkt), in_pkt))
             return -1;
         if(memcmp(in_pkt, data_pkt, 4)){
             ckb_err("Bad input header");
@@ -93,7 +110,7 @@ int loadrgb_mouse(usbdevice* kb, lighting* light, int mode){
 int updatergb_mouse_legacy(usbdevice* kb, int force){
     lighting* lastlight = &kb->profile->lastlight;
     lighting* newlight = &kb->profile->currentmode->light;
-    // Don't do anything if the lighting hasn't changed        
+    // Don't do anything if the lighting hasn't changed
     // We only use "back" on the legacy M95 for consistency
     // 0x00 on R, G and B channels is off
     // Anything else is on
@@ -103,11 +120,11 @@ int updatergb_mouse_legacy(usbdevice* kb, int force){
     if(!force && !lastlight->forceupdate && !newlight->forceupdate && lastwValue == newwValue)
         return 0;
     lastlight->forceupdate = newlight->forceupdate = 0;
-    
+
     lastlight->r[MOUSE_BACK_LED] = newlight->r[MOUSE_BACK_LED];
     lastlight->g[MOUSE_BACK_LED] = newlight->g[MOUSE_BACK_LED];
     lastlight->b[MOUSE_BACK_LED] = newlight->b[MOUSE_BACK_LED];
 
-    usbsend_control(kb, NULL, 0, 49, newwValue, 0);
+    usbsend(kb, (&(ctrltransfer) { .bRequestType = 0x40, .bRequest = 49, .wValue = newwValue, .wIndex = 0, .wLength = 0, .timeout = 5000, .data = NULL }), 0, 1);
     return 0;
 }
