@@ -10,13 +10,14 @@
 #include <string.h>
 #include "keymap_patch.h"
 
+#define TERM_REV_VID "\033[7m"
+#define TERM_NORM    "\033[0m"
+
 // usb.c
 extern _Atomic int reset_stop;
 extern int features_mask;
 extern int enable_experimental;
-// device.c
-extern int hwload_mode;
-
+extern const char pidpath[];
 int sighandler_pipe[2] = { 0, 0 };
 
 // Timespec utility function
@@ -139,34 +140,30 @@ void localecase(char* dst, size_t length, const char* src){
     *dst = 0;
 }
 
+// For --search
+extern void fill_usbdevice_protocol(usbdevice* kb);
+
 int main(int argc, char** argv){
     // Set output pipes to buffer on newlines, if they weren't set that way already
     setlinebuf(stdout);
     setlinebuf(stderr);
 
-    printf("ckb-next: Corsair RGB driver %s\n", CKB_NEXT_VERSION_STR);
     // If --help occurs anywhere in the command-line, don't launch the program but instead print usage
     for(int i = 1; i < argc; i++){
         if(!strcmp(argv[i], "--help")){
             printf(
 #ifdef OS_MAC_LEGACY
-                        "Usage: ckb-next-daemon [--version] [--gid=<gid>] [--hwload=<always|try|never>] [--nonotify] [--nobind] [--nomouseaccel] [--nonroot]\n"
+                        "Usage: ckb-next-daemon [--version] [--gid=<gid>] [--nonotify] [--nobind] [--nomouseaccel] [--nonroot]\n"
 #else
-                        "Usage: ckb-next-daemon [--version] [--gid=<gid>] [--hwload=<always|try|never>] [--nonotify] [--nobind] [--nonroot]\n"
+                        "Usage: ckb-next-daemon [--version] [--gid=<gid>] [--nonotify] [--nobind] [--nonroot]\n"
 #endif
-                        "\n"
-                        "See https://github.com/ckb-next/ckb-next/wiki/CKB-Daemon-Manual for full instructions.\n"
-                        "\n"
-                        "Command-line parameters:\n"
+                        "%s\n\n"
+                        "Options:\n"
                         "    --version\n"
                         "        Print version string to stdout and quit.\n"
                         "    --gid=<gid>\n"
                         "        Restrict access to %s* nodes to users in group <gid>.\n"
                         "        (Ordinarily they are accessible to anyone)\n"
-                        "    --hwload=<always|try|never>\n"
-                        "        --hwload=always will force loading of stored hardware profiles on compatible devices. May result in long start up times.\n"
-                        "        --hwload=try will try to load the profiles, but give up if not immediately successful (default).\n"
-                        "        --hwload=never will ignore hardware profiles completely.\n"
                         "    --nonotify\n"
                         "        Disables key monitoring/notifications.\n"
                         "        Note that this makes reactive lighting impossible.\n"
@@ -178,29 +175,36 @@ int main(int argc, char** argv){
 #endif
                         "    --nonroot\n"
                         "        Allows running ckb-next-daemon as a non root user.\n"
-                        "        This will almost certainly not work. Use only if you know what you're doing.\n"
-                        "\n", devpath);
-            exit(0);
+                        "        This will almost certainly not work. Use only if you know what you're doing.\n",
+                        CKB_NEXT_DESCRIPTION, devpath);
+            return 0;
         } else if (!strcmp(argv[i], "--version")){
+            printf("ckb-next-daemon %s\n", CKB_NEXT_VERSION_STR);
             return 0;
         }
     }
 
+    printf("ckb-next-daemon %s\n", CKB_NEXT_VERSION_STR);
+
 #ifdef OS_MAC
     if(argc == 2 && getuid() != 0 && !(strcmp(argv[1], "--request-hid-permission-because-it-doesnt-work-as-root-thanks-apple")))
         return request_hid_access_mac();
 #endif
 
     // Check PID, quit if already running
-    if(is_pid_running())
+    pid_t dpid;
+    if((dpid = is_pid_running())){
+        ckb_fatal_nofile("ckb-next-daemon is already running (PID %ld).", (long)dpid);
+        ckb_fatal_nofile("Try `systemctl stop ckb-next-daemon` or `killall ckb-next-daemon`.");
+        ckb_fatal_nofile("(If you're certain the process is dead, delete %s and try again.)", pidpath);
         return 1;
+    }
 
     // Read parameters
     int forceroot = 1;
     for(int i = 1; i < argc; i++){
         char* argument = argv[i];
         unsigned newgid;
-        char hwload[8];
         ushort vid, pid;
         if(sscanf(argument, "--gid=%u", &newgid) == 1){
             // Set dev node GID
@@ -214,17 +218,6 @@ int main(int argc, char** argv){
             // Disable key notifications
             features_mask &= ~FEAT_NOTIFY;
             ckb_info_nofile("Key notifications are disabled");
-        } else if(sscanf(argument, "--hwload=%7s", hwload) == 1){
-            if(!strcmp(hwload, "always") || !strcmp(hwload, "yes") || !strcmp(hwload, "y") || !strcmp(hwload, "a")){
-                hwload_mode = 2;
-                ckb_info_nofile("Setting hardware load: always");
-            } else if(!strcmp(hwload, "tryonce") || !strcmp(hwload, "try") || !strcmp(hwload, "once") || !strcmp(hwload, "t") || !strcmp(hwload, "o")){
-                hwload_mode = 1;
-                ckb_info_nofile("Setting hardware load: tryonce");
-            } else if(!strcmp(hwload, "never") || !strcmp(hwload, "none") || !strcmp(hwload, "no") || !strcmp(hwload, "n")){
-                hwload_mode = 0;
-                ckb_info_nofile("Setting hardware load: never");
-            }
         } else if(!strcmp(argument, "--nonroot")){
             // Allow running as a non-root user
             forceroot = 0;
@@ -248,8 +241,13 @@ int main(int argc, char** argv){
                     searchstr++;
             }
 
+            // We need to call this before patchkeys, otherwise the bragi keymap will never be applied
+            fill_usbdevice_protocol(&dev);
+
             patchkeys(&dev);
 
+            int found = -1;
+
             // Search through the patched keymap
             for (int j = 0; j < N_KEYS_EXTENDED; j++) {
                 // Special case, where we're searching for the first NULL entry
@@ -257,17 +255,40 @@ int main(int argc, char** argv){
                     if (*searchstr != '\0')
                         continue;
 
-                    printf("First NULL key has id %d\n", j);
-                    return 0;
+                    found = j;
+                    break;
                 }
 
                 if (!strcasecmp(searchstr, dev.keymap[j].name)) {
-                    printf("Key %s has id %d\n", dev.keymap[j].name, j);
-                    return 0;
+                    found = j;
+                    break;
                 }
             }
-            printf("Key %s was not found\n", searchstr);
-            return 1;
+
+            for (int j = 0; j < N_KEYS_EXTENDED; j++) {
+                if(j == found)
+                    fputs(TERM_REV_VID, stdout);
+
+                printf("{ %10s, %3hd, %4hd },", (dev.keymap[j].name ? dev.keymap[j].name : "NULL"),
+                    dev.keymap[j].led, dev.keymap[j].scan);
+
+                if(j == found)
+                    fputs(TERM_NORM, stdout);
+                putchar('\n');
+            }
+
+            putchar('\n');
+
+            if(found == -1) {
+                printf("Key %s was not found\n", searchstr);
+                return 1;
+            } else if (*searchstr == '\0') {
+                printf("First NULL key has id %d\n", found);
+            } else {
+                printf("Key %s has id %d\n", dev.keymap[found].name, found);
+            }
+
+            return 0;
         } else if(!strcmp(argument, "--enable-experimental")) {
             enable_experimental = 1;
 #ifdef ckb_next_VERSION_IS_RELEASE
