@@ -74,6 +74,8 @@ const device_desc models[] = {
     { V_CORSAIR, P_K70_MK2, },
     { V_CORSAIR, P_K70_MK2SE, },
     { V_CORSAIR, P_K70_MK2LP, },
+    { V_CORSAIR, P_K70_TKL, },
+    { V_CORSAIR, P_K70_PRO, },
     { V_CORSAIR, P_K90_LEGACY, },
     { V_CORSAIR, P_K95, },
     { V_CORSAIR, P_K95_LEGACY, },
@@ -85,6 +87,10 @@ const device_desc models[] = {
     { V_CORSAIR, P_K95_PLATINUM_XT, },
     { V_CORSAIR, P_K57_D, },
     { V_CORSAIR, P_K57_U, },
+    { V_CORSAIR, P_K100_OPTICAL, },
+    { V_CORSAIR, P_K100_MECHANICAL, },
+    { V_CORSAIR, P_K100_OPTICAL_VARIANT, },
+    { V_CORSAIR, P_K65_MINI, },
     // Mice
     { V_CORSAIR, P_M55_RGB_PRO, },
     { V_CORSAIR, P_M65, },
@@ -121,6 +127,7 @@ const device_desc models[] = {
     { V_CORSAIR, P_GLAIVE_PRO, },
     // Mousepads
     { V_CORSAIR, P_POLARIS, },
+    { V_CORSAIR, P_MM700, },
     // Headset stands
     { V_CORSAIR, P_ST100, },
     // Misc
@@ -186,6 +193,8 @@ const char* vendor_str(ushort vendor){
 /// product_str() needs the \a product \a ID
 ///
 const char* product_str(ushort product){
+    if(product == P_K100_OPTICAL || product == P_K100_MECHANICAL || product == P_K100_OPTICAL_VARIANT)
+        return "k100";
     if(product == P_K95_LEGACY)
         return "k95l";
     if(product == P_K95)
@@ -196,10 +205,16 @@ const char* product_str(ushort product){
         return "k70";
     if(product == P_K70_MK2 || product == P_K70_MK2SE || product == P_K70_MK2LP)
         return "k70mk2";
+    if(product == P_K70_TKL)
+        return "k70tkl";
+    if(product == P_K70_PRO)
+        return "k70pro";
     if(product == P_K68 || product == P_K68_NRGB)
         return "k68";
     if(product == P_K65 || product == P_K65_LEGACY || product == P_K65_LUX || product == P_K65_RFIRE)
         return "k65";
+    if(product == P_K65_MINI)
+        return "k65_mini";
     if(product == P_K66)
         return "k66";
     if(product == P_K63_NRGB)
@@ -259,6 +274,8 @@ const char* product_str(ushort product){
         return "st100";
     if(product == P_GENERIC_BRAGI_DONGLE)
         return "bragi_dongle";
+    if(product == P_MM700)
+        return "mm700";
     return "";
 }
 
@@ -284,6 +301,8 @@ static const devcmd* get_vtable(usbdevice* kb){
             return &vtable_bragi_dongle;
         else if(IS_MOUSE(vendor, product))
             return &vtable_bragi_mouse;
+        else if(IS_MOUSEPAD(vendor, product))
+            return &vtable_bragi_mousepad;
         else
             return &vtable_bragi_keyboard;
     } else if(IS_MOUSE(vendor, product)) {
