@@ -10,7 +10,7 @@ class CkbUpdater : public QObject
 {
     Q_OBJECT
 public:
-    explicit CkbUpdater(QObject *parent = 0);
+    explicit CkbUpdater(QObject *parent = nullptr);
     void checkForNewVersion();
 
 private:
