@@ -12,7 +12,7 @@ class ExtraSettingsWidget : public QWidget
     Q_OBJECT
 
 public:
-    explicit ExtraSettingsWidget(QWidget *parent = 0);
+    explicit ExtraSettingsWidget(QWidget *parent = nullptr);
     ~ExtraSettingsWidget();
 
     void pollUpdates();
@@ -32,6 +32,7 @@ private slots:
     void on_timerBox_clicked(bool checked);
     void on_timerMinBox_editingFinished();
     void on_monochromeBox_toggled(bool checked);
+    void on_msaaBox_toggled(bool checked);
 
 private:
     Ui::ExtraSettingsWidget *ui;
