@@ -50,7 +50,7 @@ public:
     // Global key remap (changes modifiers per Settings widget)
     // Use only when iterating the map manually; all KbBind functions already take this into account
     static QString  globalRemap(const QString& key);
-    static void     setGlobalRemap(const QHash<QString, QString> keyToActual);
+    static void     setGlobalRemap(const QHash<QString, QString>& keyToActual);
     static void     loadGlobalRemap();
     static void     saveGlobalRemap();
 
@@ -118,8 +118,8 @@ private:
     KeyAction* bindAction(const QString& key);
 
     static QHash<QString, QString>  _globalRemap;
-    static quint64                  globalRemapTime;
-    quint64                         lastGlobalRemapTime;
+    static qint64                  globalRemapTime;
+    qint64                         lastGlobalRemapTime;
 
     //////////
     /// \brief lastCmd is a cache-hack.
