@@ -31,7 +31,7 @@ extern QString devpath;
 
 int MainWindow::signalHandlerFd[2] = {0, 0};
 
-MainWindow* MainWindow::mainWindow = 0;
+MainWindow* MainWindow::mainWindow = nullptr;
 
 #if defined(Q_OS_MACOS) && !defined(OS_MAC_LEGACY)
 bool is_catalina_or_higher(){
@@ -115,7 +115,7 @@ void MainWindow::appleRequestHidTimer(){
 }
 #endif
 
-MainWindow::MainWindow(QWidget *parent) :
+MainWindow::MainWindow(const bool silent, QWidget *parent) :
     QMainWindow(parent),
     ui(new Ui::MainWindow)
 {
@@ -169,10 +169,12 @@ MainWindow::MainWindow(QWidget *parent) :
     QMessageBox dialog;
     dialog.setText(tr("The ckb-next daemon is not running. This program will <b>not</b> work without it!"));
 #ifndef Q_OS_MACOS
-    QString daemonDialogText = QString(tr("Start it once with:")) +
+    QString daemonDialogText = tr("Start it once with:") +
     "<blockquote><code>sudo systemctl start ckb-next-daemon</code></blockquote>" +
     tr("Enable it for every boot:") +
-    "<blockquote><code>sudo systemctl enable ckb-next-daemon</code></blockquote>";
+    "<blockquote><code>sudo systemctl enable ckb-next-daemon</code></blockquote><br>" +
+    tr("If \"Unit ckb-next-daemon.service is masked.\", unmask it first and try again:") +
+    "<blockquote><code>sudo systemctl unmask ckb-next-daemon</code></blockquote>";
 #else
     QString daemonDialogText = QString(tr("Start and enable it with:")) +
     "<blockquote><code>sudo launchctl load -w /Library/LaunchDaemons/org.ckb-next.daemon.plist</code></blockquote>";
@@ -196,7 +198,7 @@ MainWindow::MainWindow(QWidget *parent) :
     // `.arg(0)` is necessary to interpolate the correct suffix into the path
     // see `./kbmanager.cpp` for details
     QFileInfo rootDevPath(devpath.arg(0));
-    if (!rootDevPath.exists()) {
+    if (!(rootDevPath.exists()  || silent)) {
         // set settings widget's status
         // show the main window (otherwise only the dialog will be visible)
         // finally show the dialog
@@ -516,7 +518,7 @@ void MainWindow::QSignalHandler(){
     qDebug() << "\nSignal" << sig << "caught. Quitting...";
     if(sig == SIGHUP){
         // Restart, but with a delay
-        QProcess::startDetached(QCoreApplication::applicationFilePath(), QStringList() << "-b" << "-d");
+        QProcess::startDetached(QCoreApplication::applicationFilePath(), QStringList() << "-b" << "-d" << "-s");
     }
     this->quitApp();
     sigNotifier->setEnabled(true);
