@@ -1,7 +1,8 @@
 #include "modeselectdialog.h"
+
 #include "ui_modeselectdialog.h"
 
-ModeSelectDialog::ModeSelectDialog(QWidget* parent, KbMode* currentMode, QList<KbMode*> modeList, const QString& textLabel) :
+ModeSelectDialog::ModeSelectDialog(QWidget* parent, KbMode* currentMode, const QList<KbMode*>& modeList, const QString& textLabel) :
     QDialog(parent), ui(new Ui::ModeSelectDialog),
     _modeList(modeList)
 {
