@@ -16,7 +16,7 @@ class SettingsWidget : public QWidget
     Q_OBJECT
 
 public:
-    explicit SettingsWidget(QWidget *parent = 0);
+    explicit SettingsWidget(QWidget *parent = nullptr);
     ~SettingsWidget();
 
     // Set text labels
